# Kansas

> This state uses the Job Center platform. See the [Job Center docs](job_center.md)
> for details on the scraping strategy.

- [Home page](https://www.kansasworks.com)
- [Search form](https://www.kansasworks.com/search/warn_lookups/new)
- [All data][]
- General contact number (1-800) listed [here](https://www.kansasworks.com/site_map)

## Important data note

The Kansas Job Center site does not display Non-WARN layoff notices by default but our scraper captures both WARN and Non-WARN notices. Therefore, our record counts are significantly higher than what you'll get from a count of records displayed online.

[All data]: https://www.kansasworks.com/search/warn_lookups?commit=Search&page=1&q%5Bemployer_name_cont%5D=&q%5Bmain_contact_contact_info_addresses_full_location_city_matches%5D=&q%5Bnotice_eq%5D=true&q%5Bnotice_on_gteq%5D=&q%5Bnotice_on_lteq%5D=&q%5Bs%5D=notice_on+desc&q%5Bservice_delivery_area_id_eq%5D=&q%5Bzipcode_code_start%5D=&utf8=%E2%9C%93
